@@ -14,7 +14,7 @@ package Debug::Fork::Tmux;
 use strict;
 use warnings;
 
-our $VERSION = '1.000007';    # VERSION
+our $VERSION = '1.000009';    # VERSION
 #
 ### MODULES ###
 #
@@ -200,7 +200,7 @@ Debug::Fork::Tmux - Makes fork() in debugger to open a new Tmux window
 
 =head1 VERSION
 
-This documentation refers to the module contained in the distribution C<Debug-Fork-Tmux> version 1.000007.
+This documentation refers to the module contained in the distribution C<Debug-Fork-Tmux> version 1.000009.
 
 =head1 SYNOPSIS
 
@@ -218,12 +218,13 @@ This documentation refers to the module contained in the distribution C<Debug-Fo
 
 The real usage example of this module is:
 
-    perl -MDebug::Fork::Tmux -d your_script.pl
+    $ perl -MDebug::Fork::Tmux -d your_script.pl
 
-The Perl's standard debugger requires additional stuff when the debugged
-Perl program use the L<fork()|perlfunc/fork> built-in.
+As Perl's standard debugger requires additional code to be written and used
+when the debugged Perl program use the L<fork()|perlfunc/fork> built-in.
 
-This module is about to solve the trouble which visible like this:
+This module is about to solve the trouble which is used to be observed like
+this:
 
   ######### Forked, but do not know how to create a new TTY. #########
   Since two debuggers fight for the same TTY, input is severely entangled.
@@ -236,23 +237,35 @@ This module is about to solve the trouble which visible like this:
   On UNIX-like systems one can get the name of a TTY for the given window
   by typing tty, and disconnect the shell from TTY by sleep 1000000.
 
-C<OS/2> is a fun for me but in the past. C<Mac OS X> is a more chance but
-still isn't real. And for C<xterm> ... who wants to keep it on your server?
-Gimme some stones to throw on that one.
+All of that is about getting the pseudo-terminal device for another part of
+user interface. This is probably why only the C<GUI>s are mentioned here:
+C<OS/2> 'Command Prompt', C<Mac OS X>'s C<Terminal.app> and an C<xterm>. For
+those of you who develop server-side stuff it should be known that keeping
+C<GUI> on the server is far from always to be available as an option no
+matter if it's a production or a development environment.
 
-But the pseudo-terminal device isn't much about C<GUI>s by its nature so the
-problem behind the bars of the L<perl5db.pl> report ( see more detailed
+The most ridiculous for every C<TUI> (the C<ssh> particularly) user is that
+the pseudo-terminal device isn't that much about C<GUI>s by its nature so
+the problem behind the bars of the L<perl5db.pl> report (see more detailed
 problem description at the L<PerlMonks
-thread|http://perlmonks.org/?node_id=128283> ) is the consoles management.
+thread|http://perlmonks.org/?node_id=128283>) is the consoles management.
 It's a kind of a tricky, for example, to start the next C<ssh> session
 initiated from the machine serving as an C<sshd> server for the existing
 session.
 
-Thus we kind of have to give a chance to the consoles management with
-a software capable to run on a server machine without as much dependencies
-as an C<xterm>. This module is a try to pick the L<Tmux|http://tmux.sf.net>
+Thus we kind of have to give a chance to the consoles management with a
+software capable to run on a server machine without as much dependencies as
+an C<xterm>. This module is a try to pick the L<Tmux|http://tmux.sf.net>
 windows manager for such a task.
 
+Because of highly-developed scripting capabilities of C<Tmux> any user can
+supply the 'window' or a 'pane' to Perl's debugger making it suitable to
+debug the separate process in a different C<UI> instance. Also this adds the
+features like C<groupware>: imagine that your mate can debug the process
+you've just C<fork()ed> by mean of attaching the same C<tmux> you are
+running on a server. While you keep working on a process that called a
+C<fork()>.
+
 =head1 SUBROUTINES/METHODS
 
 All of the following are functions:
